@@ -19,10 +19,9 @@ class UMLObject;
 
  * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
-class SQLImport : public QObject, public NativeImportBase {
-    Q_OBJECT
+class SQLImport : public NativeImportBase {
 public:
-    explicit SQLImport(CodeImpThread* thread = 0);
+    explicit SQLImport(CodeImpThread *thread = nullptr);
     virtual ~SQLImport();
 
     bool parseStmt();
